@@ -1,4 +1,4 @@
-/* $Id: gucharmap-search-dialog.c,v 1.12 2004/02/25 22:15:38 nlevitt Exp $ */
+/* $Id: gucharmap-search-dialog.c,v 1.14 2004/03/07 17:28:37 nlevitt Exp $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -724,7 +724,11 @@ gucharmap_search_dialog_get_completed (GucharmapSearchDialog *search_dialog)
     return -1.0;
   else
     {
+#if ENABLE_UNIHAN
       gdouble total = gucharmap_get_unicode_data_name_count () + gucharmap_get_unihan_count ();
+#else
+      gdouble total = gucharmap_get_unicode_data_name_count ();
+#endif
       return (gdouble) priv->search_state->strings_checked / total;
     }
 }
